from setuptools import setup, find_packages
setup(name="istrings", version="0.0.1",
      py_modules=['istrings'],
      url="http://github.com/bobuk/istrings",
      author="Grigory Bakunov",
      author_email='thebobuk@ya.ru',
      description='Simple module to work with interface texts outside of the main code',
      classifiers = [
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Development Status :: 4 - Beta",
        "Environment :: Other Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
      ],

)
